@@ -9,13 +9,13 @@ use UNIVERSAL::isa;
 use Scalar::Util qw(blessed reftype);
 use Net::LDAP::LDIF;
 
-use version; our $VERSION = qv('0.0.9');
+use version; our $VERSION = qv('0.0.10');
 
 sub new {
     my ( $class, $param ) = @_;
     my $self = bless( { list => undef }, $class );
 
-    return $self unless $param;
+    croak 'Must pass parameter' unless $param;
 
     $self->load($param);
 
@@ -60,6 +60,9 @@ sub _open_ldif {
         );
     }
 
+    # Then, it must be a filename
+    croak q{Cannot find file "} . $param . q{"} unless -r $param;
+
     return Net::LDAP::LDIF->new($param);
 }
 
