@@ -9,19 +9,24 @@ use fields qw(store);
 
 use Carp;
 use Net::LDAP::LDIF;
+use Scalar::Util qw{blessed};
+use UNIVERSAL::isa;
 
-use version; our $VERSION = qv('0.0.9');
+use version; our $VERSION = qv('0.0.10');
 
 sub new {
     my $class = shift;
     my $store = shift;
     my $self  = $class->SUPER::new(@_);
 
+    croak 'Must pass store!' unless $store;
+    croak 'Not an object!'   unless blessed($store);
+    croak 'Not a LDIFStore!'
+      unless $store->isa('Net::LDAP::SimpleServer::LDIFStore');
+
     #printf "Accepted connection from: %s\n", $sock->peerhost();
     $self->{store} = $store;
 
-    croak 'Must pass store!' unless $store;
-
     return $self;
 }
 
